@@ -14,8 +14,8 @@ use WebService::LiveJournal::EventList;
 use WebService::LiveJournal::Tag;
 use HTTP::Cookies;
 
-# ABSTRACT: Interface to the LiveJournal API
-our $VERSION = '0.08'; # VERSION
+# ABSTRACT: (Deprecated) Interface to the LiveJournal API
+our $VERSION = '0.09'; # VERSION
 
 
 my $zero = new RPC::XML::int(0);
@@ -618,11 +618,11 @@ __END__
 
 =head1 NAME
 
-WebService::LiveJournal::Client - Interface to the LiveJournal API
+WebService::LiveJournal::Client - (Deprecated) Interface to the LiveJournal API
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -645,6 +645,11 @@ See L<WebService::LiveJournal::FriendGroup> for getting your friend groups.
 
 =head1 DESCRIPTION
 
+B<NOTE>: This distribution is deprecated.  It uses the outmoded XML-RPC protocol.
+LiveJournal has also been compromised.  I recommend using DreamWidth instead
+(L<https://www.dreamwidth.org/>) which is in keeping with the original philosophy
+LiveJournal regarding advertising.
+
 This is a client class for communicating with LiveJournal using its API.  It is different
 from the other LJ modules on CPAN in that it originally used the XML-RPC API.  It now
 uses a hybrid of the flat and XML-RPC API to avoid bugs in some LiveJournal deployments.
