@@ -5,8 +5,8 @@ use warnings;
 use WebService::LiveJournal::Thingie;
 our @ISA = qw/ WebService::LiveJournal::Thingie /;
 
-# ABSTRACT: LiveJournal friend class
-our $VERSION = '0.08'; # VERSION
+# ABSTRACT: (Deprecated) LiveJournal friend class
+our $VERSION = '0.09'; # VERSION
 
 
 sub new
@@ -48,11 +48,11 @@ __END__
 
 =head1 NAME
 
-WebService::LiveJournal::Friend - LiveJournal friend class
+WebService::LiveJournal::Friend - (Deprecated) LiveJournal friend class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -78,6 +78,11 @@ version 0.08
 
 =head1 DESCRIPTION
 
+B<NOTE>: This distribution is deprecated.  It uses the outmoded XML-RPC protocol.
+LiveJournal has also been compromised.  I recommend using DreamWidth instead
+(L<https://www.dreamwidth.org/>) which is in keeping with the original philosophy
+LiveJournal regarding advertising.
+
 This class represents a friend or user on the LiveJournal server.
 
 =head1 ATTRIBUTES
