@@ -6,8 +6,8 @@ use WebService::LiveJournal::List;
 use WebService::LiveJournal::Friend;
 our @ISA = qw/ WebService::LiveJournal::List /;
 
-# ABSTRACT: List of LiveJournal friends
-our $VERSION = '0.08'; # VERSION
+# ABSTRACT: (Deprecated) List of LiveJournal friends
+our $VERSION = '0.09'; # VERSION
 
 
 sub init
@@ -68,14 +68,19 @@ __END__
 
 =head1 NAME
 
-WebService::LiveJournal::FriendList - List of LiveJournal friends
+WebService::LiveJournal::FriendList - (Deprecated) List of LiveJournal friends
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
+B<NOTE>: This distribution is deprecated.  It uses the outmoded XML-RPC protocol.
+LiveJournal has also been compromised.  I recommend using DreamWidth instead
+(L<https://www.dreamwidth.org/>) which is in keeping with the original philosophy
+LiveJournal regarding advertising.
+
 List of friends returned from L<WebService::LiveJournal>.
 See L<WebService::LiveJournal::Friend> for how to use
 this class.
